@@ -1,7 +1,7 @@
 package Perinci::Object::EnvResultMulti;
 
-our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2017-02-03'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010;
 use strict;
@@ -22,7 +22,7 @@ sub add_result {
     my $num_nok = 0;
 
     push @{ ${$self}->[3]{results} },
-        {%{ $extra // {} }, status=>$status, message=>$message};
+        {status=>$status, message=>$message, %{ $extra // {} }};
     for (@{ ${$self}->[3]{results} // [] }) {
         if ($_->{status} =~ /\A(2|304)/) {
             $num_ok++;
@@ -59,7 +59,7 @@ Perinci::Object::EnvResultMulti - Represent enveloped result (multistatus)
 
 =head1 VERSION
 
-This document describes version 0.28 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2016-12-27.
+This document describes version 0.30 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2017-02-03.
 
 =head1 SYNOPSIS
 
@@ -119,7 +119,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ob
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Object>.
 
 =head1 BUGS
 
@@ -141,7 +141,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
